/*
 * CodeConversion.h
 *
 * Copyright (C) 2021 OPTOELECTRONICS CO.,LTD. All rights reserved.
 */

#ifndef CODECONVERSION_H_
#define CODECONVERSION_H_

#include <stdlib.h>

//////////////////////////////////////////////
// DEBUG log flags
//////////////////////////////////////////////
extern int DBG_CODE_CONVERSION;

//////////////////////////////////////////////
//Utf8 code conversion APIs
//////////////////////////////////////////////
#define CONV_INVALID_PARAMETER_ERROR		1
#define CONV_MEMORY_ALLOCATION_ERROR		2
#define CONV_INVALID_UTF8_FORMAT_ERROR		3
#define CONV_UNSUPPORTED_CODE_WARNING		100

#define UNSUPPORTED_CODE_MARK				'?'	// 0x3F

//String conversion for CP437_ose
char *CONV_Utf8ToCP437oseString(char *src, int length, int *error_code, size_t *output_length);
char *CONV_CP437oseToUtf8String(char *src, int length, int *error_code, size_t *output_length);

//String conversion for SJIS
char *CONV_Utf8ToSjisString(char *src, int length, int *error_code, size_t *output_length);
char *CONV_SjisToUtf8String(char *src, int length, int *error_code, size_t *output_length);

//Single code conversion for CP437_ose
int CONV_CP437oseToUnicode(int code);
char *CONV_UnicodeToCP437ose(unsigned short unicode);

//Single code conversion for SJIS
int CONV_SjisToUnicode(int sjis);
char *CONV_UnicodeToSjis(unsigned short unicode);

//Custom string conversion
typedef int (*CONV_LOCAL_TO_UNICODE)(int localByte);
char *CONV_LocalToUtf8String(char *src, int length, int *error_code, size_t *output_length, CONV_LOCAL_TO_UNICODE LocalToUnicodeCallback);
typedef char * (*CONV_UNICODE_TO_LOCAL)(unsigned short unicode);
char *CONV_Utf8ToLocalString(char *src, int length, int *error_code, size_t *output_length, CONV_UNICODE_TO_LOCAL UnicodeToLocalCallback);

int CONV_UnicodeToUtf8(int unicode, char **wp);

#endif /* CODECONVERSION_H_ */
